pub struct SqliteContextStore { /* private fields */ }Expand description
SQLite-backed ContextStore implementation.
Uses WAL mode for concurrent read access and a single Mutex<Connection>
for thread-safe write access. All data is stored in two STRICT tables:
outputs for node outputs and globals for global key-value pairs.
Implementations
Sourceimpl SqliteContextStore
impl SqliteContextStore
Sourcepub fn open(path: impl AsRef<Path>) -> Result<Self, ContextStoreError>
pub fn open(path: impl AsRef<Path>) -> Result<Self, ContextStoreError>
Open or create a ContextStore at the given path.
Creates the database file and tables if they don’t exist. Enables WAL mode and sets a busy timeout for concurrent access.
Sourcepub fn in_memory() -> Result<Self, ContextStoreError>
pub fn in_memory() -> Result<Self, ContextStoreError>
Create an in-memory ContextStore (for testing).